==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/Performance/src/com/clustercontrol/performance/view/action/RealtimeSetGraphAction2.java <==
/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 */

package com.clustercontrol.performance.view.action;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.IViewActionDelegate;
import org.eclipse.ui.IViewPart;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.PlatformUI;

import com.clustercontrol.performance.dialog.RealtimeSetDialog2;
import com.clustercontrol.performance.util.Messages;
import com.clustercontrol.performance.view.RealtimeGraphView;

/**
 * ѤߥǡΥꥹɽԤView饹
 * 
 * @version 1.0
 * @since 1.0
 */
public class RealtimeSetGraphAction2 implements IViewActionDelegate {
    private RealtimeSetDialog2 dialog;
    private static RealtimeGraphView performanceView = new RealtimeGraphView();

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
     */
    public void init(IViewPart view) {
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.com.realtimemonitor.action.IAction)
     */
    //ɽϿɽȥ
    public void run(IAction action) {
        /*
         * ƤӽФViewäƤޤ
         */
        IWorkbenchPage page = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage();
        RealtimeGraphView view = (RealtimeGraphView) page.findView(Messages.getString("VIEW_REALTIME_GRAPH"));

        Shell shell = new Shell();
        dialog = new RealtimeSetDialog2(shell);
        
        dialog.setCollectorInfo(view.collectorInfo);
        dialog.setCollectorItemInfo(view.collectorItemInfo);
        dialog.setInterval(false);
        dialog.update();
        
        int ret = dialog.open();
        
        // OKܥ󤬲줿Ȥν
        if (ret == IDialogConstants.OK_ID) {
            /*
             * ֥׿10Ķĥ֥ɽͤɽ褦Ȥηٹ
             *     ǤݡŪˤϥ顼ɽʤ
             */
        	//
        	  
        	if (view.graphComposite != null) {
            	view.graphComposite.setValueaxisRange(
            			view.collectorInfo.getGraphPlotNum(),
            			view.collectorInfo.getInterval());
        	  }
        } else if (ret == IDialogConstants.CANCEL_ID) {
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.com.realtimemonitor.action.IAction,
     *      org.eclipse.jface.viewers.ISelection)
     */
    public void selectionChanged(IAction action, ISelection selection) {

    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/Performance/src/com/clustercontrol/performance/view/action/RealtimeSetGraphAction2.java <==
/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 */

package com.clustercontrol.performance.view.action;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.IViewActionDelegate;
import org.eclipse.ui.IViewPart;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.PlatformUI;

import com.clustercontrol.performance.dialog.RealtimeSetDialog2;
import com.clustercontrol.performance.util.Messages;
import com.clustercontrol.performance.view.RealtimeGraphView;

/**
 * 収集済みデータのリスト表示を行うViewクラス
 * 
 * @version 1.0
 * @since 1.0
 */
public class RealtimeSetGraphAction2 implements IViewActionDelegate {
    private RealtimeSetDialog2 dialog;
    private static RealtimeGraphView performanceView = new RealtimeGraphView();

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
     */
    public void init(IViewPart view) {
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.com.realtimemonitor.action.IAction)
     */
    //グラフ表示する条件を登録するダイアログの表示とアクション。
    public void run(IAction action) {
        /*
         * 呼び出し元のViewを持ってきます。
         */
        IWorkbenchPage page = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage();
        RealtimeGraphView view = (RealtimeGraphView) page.findView(Messages.getString("VIEW_REALTIME_GRAPH"));

        Shell shell = new Shell();
        dialog = new RealtimeSetDialog2(shell);
        
        dialog.setCollectorInfo(view.collectorInfo);
        dialog.setCollectorItemInfo(view.collectorItemInfo);
        dialog.setInterval(false);
        dialog.update();
        
        int ret = dialog.open();
        
        // 条件設定ダイアログでOKボタンが押下されたときの処理
        if (ret == IDialogConstants.OK_ID) {
            /*
             * サブスコープ数が10を超えかつサブスコープ代表値を表示しようとした時の警告ダイアログ
             *     いちいちダイアログがでると面倒。基本的にはエラーダイアログは表示しない。
             */
        	//
        	  
        	if (view.graphComposite != null) {
            	view.graphComposite.setValueaxisRange(
            			view.collectorInfo.getGraphPlotNum(),
            			view.collectorInfo.getInterval());
        	  }
        } else if (ret == IDialogConstants.CANCEL_ID) {
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.com.realtimemonitor.action.IAction,
     *      org.eclipse.jface.viewers.ISelection)
     */
    public void selectionChanged(IAction action, ISelection selection) {

    }
}
